pub struct Invalidation {
pub fact_id: String,
pub reason: String,
}Expand description
One existing fact the extractor proposes to invalidate (contradicted by this turn).
Fields
fact_id: StringThe id of the existing fact whose validity interval should close.
reason: StringWhy (one short phrase).